@@ -11,8 +11,7 @@
  * information regarding copyright ownership.
  */
 
-#ifndef DNS_CLIENTINFO_H
-#define DNS_CLIENTINFO_H 1
+#pragma once
 
 /*****
 ***** Module Info
@@ -58,13 +57,13 @@ ISC_LANG_BEGINDECLS
  */
 typedef struct dns_clientinfo {
 	uint16_t  version;
-	void     *data;
-	void     *dbversion;
+	void	 *data;
+	void	 *dbversion;
 	dns_ecs_t ecs;
 } dns_clientinfo_t;
 
 typedef isc_result_t (*dns_clientinfo_sourceip_t)(dns_clientinfo_t *client,
-						  isc_sockaddr_t	 **addrp);
+						  isc_sockaddr_t  **addrp);
 
 #define DNS_CLIENTINFOMETHODS_VERSION 2
 #define DNS_CLIENTINFOMETHODS_AGE     1
@@ -91,5 +90,3 @@ dns_clientinfo_init(dns_clientinfo_t *ci, void *data, dns_ecs_t *ecs,
 		    void *versionp);
 
 ISC_LANG_ENDDECLS
-
-#endif /* DNS_CLIENTINFO_H */
