@@ -11,8 +11,7 @@
  * information regarding copyright ownership.
  */
 
-#ifndef ISC_BUFFER_H
-#define ISC_BUFFER_H 1
+#pragma once
 
 /*****
 ***** Module Info
@@ -107,7 +106,6 @@
 #include <isc/assertions.h>
 #include <isc/formatcheck.h>
 #include <isc/lang.h>
-#include <isc/likely.h>
 #include <isc/magic.h>
 #include <isc/types.h>
 
@@ -902,7 +900,7 @@ ISC_LANG_ENDDECLS
 
 #define ISC__BUFFER_PUTMEM(_b, _base, _length)                            \
 	do {                                                              \
-		if (ISC_UNLIKELY((_b)->autore)) {                         \
+		if ((_b)->autore) {                                       \
 			isc_buffer_t *_tmp = _b;                          \
 			ISC_REQUIRE(isc_buffer_reserve(&_tmp, _length) == \
 				    ISC_R_SUCCESS);                       \
@@ -920,7 +918,7 @@ ISC_LANG_ENDDECLS
 		unsigned int   _length;                                   \
 		unsigned char *_cp;                                       \
 		_length = (unsigned int)strlen(_source);                  \
-		if (ISC_UNLIKELY((_b)->autore)) {                         \
+		if ((_b)->autore) {                                       \
 			isc_buffer_t *_tmp = _b;                          \
 			ISC_REQUIRE(isc_buffer_reserve(&_tmp, _length) == \
 				    ISC_R_SUCCESS);                       \
@@ -936,7 +934,7 @@ ISC_LANG_ENDDECLS
 		unsigned char *_cp;                                 \
 		/* evaluate (_val) only once */                     \
 		uint8_t _val2 = (_val);                             \
-		if (ISC_UNLIKELY((_b)->autore)) {                   \
+		if ((_b)->autore) {                                 \
 			isc_buffer_t *_tmp = _b;                    \
 			ISC_REQUIRE(isc_buffer_reserve(&_tmp, 1) == \
 				    ISC_R_SUCCESS);                 \
@@ -952,7 +950,7 @@ ISC_LANG_ENDDECLS
 		unsigned char *_cp;                                 \
 		/* evaluate (_val) only once */                     \
 		uint16_t _val2 = (_val);                            \
-		if (ISC_UNLIKELY((_b)->autore)) {                   \
+		if ((_b)->autore) {                                 \
 			isc_buffer_t *_tmp = _b;                    \
 			ISC_REQUIRE(isc_buffer_reserve(&_tmp, 2) == \
 				    ISC_R_SUCCESS);                 \
@@ -969,7 +967,7 @@ ISC_LANG_ENDDECLS
 		unsigned char *_cp;                                 \
 		/* evaluate (_val) only once */                     \
 		uint32_t _val2 = (_val);                            \
-		if (ISC_UNLIKELY((_b)->autore)) {                   \
+		if ((_b)->autore) {                                 \
 			isc_buffer_t *_tmp = _b;                    \
 			ISC_REQUIRE(isc_buffer_reserve(&_tmp, 3) == \
 				    ISC_R_SUCCESS);                 \
@@ -987,7 +985,7 @@ ISC_LANG_ENDDECLS
 		unsigned char *_cp;                                 \
 		/* evaluate (_val) only once */                     \
 		uint32_t _val2 = (_val);                            \
-		if (ISC_UNLIKELY((_b)->autore)) {                   \
+		if ((_b)->autore) {                                 \
 			isc_buffer_t *_tmp = _b;                    \
 			ISC_REQUIRE(isc_buffer_reserve(&_tmp, 4) == \
 				    ISC_R_SUCCESS);                 \
@@ -1063,5 +1061,3 @@ ISC_LANG_ENDDECLS
  * No inline method for this one (yet).
  */
 #define isc_buffer_putuint48 isc__buffer_putuint48
-
-#endif /* ISC_BUFFER_H */
