@@ -11,8 +11,7 @@
  * information regarding copyright ownership.
  */
 
-#ifndef ISC_UTIL_H
-#define ISC_UTIL_H 1
+#pragma once
 
 #include <inttypes.h>
 
@@ -79,7 +78,7 @@
 #if HAVE_FUNC_ATTRIBUTE_CONSTRUCTOR && HAVE_FUNC_ATTRIBUTE_DESTRUCTOR
 #define ISC_CONSTRUCTOR __attribute__((constructor))
 #define ISC_DESTRUCTOR	__attribute__((destructor))
-#elif WIN32
+#else
 #define ISC_CONSTRUCTOR
 #define ISC_DESTRUCTOR
 #endif
@@ -106,7 +105,7 @@
 	do {                           \
 		union {                \
 			const void *k; \
-			void	     *v; \
+			void	   *v; \
 		} _u;                  \
 		_u.k = konst;          \
 		var = _u.v;            \
@@ -224,7 +223,6 @@
 /*%
  * Performance
  */
-#include <isc/likely.h>
 
 /* GCC defines __SANITIZE_ADDRESS__, so reuse the macro for clang */
 #if __has_feature(address_sanitizer)
@@ -246,7 +244,12 @@
 #elif __has_feature(c_static_assert)
 #define STATIC_ASSERT(cond, msg) _Static_assert(cond, msg)
 #else /* if __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR >= 6) */
-#define STATIC_ASSERT(cond, msg) INSIST(cond)
+
+/* Courtesy of Joseph Quinsey: https://godbolt.org/z/K9RvWS */
+#define TOKENPASTE(a, b)	a##b /* "##" is the "Token Pasting Operator" */
+#define EXPAND_THEN_PASTE(a, b) TOKENPASTE(a, b) /* expand then paste */
+#define STATIC_ASSERT(x, msg) \
+	enum { EXPAND_THEN_PASTE(ASSERT_line_, __LINE__) = 1 / ((msg) && (x)) }
 #endif /* if __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR >= 6) */
 
 #ifdef UNIT_TESTING
@@ -283,9 +286,7 @@ mock_assert(const int result, const char *const expression,
 	(((a) == (b)) ? (void)0 : (_assert_int_equal(a, b, f, l), abort()))
 #define _assert_int_not_equal(a, b, f, l) \
 	(((a) != (b)) ? (void)0 : (_assert_int_not_equal(a, b, f, l), abort()))
-#else /* UNIT_TESTING */
-
-#ifndef CPPCHECK
+#else			    /* UNIT_TESTING */
 
 /*
  * Assertions
@@ -303,29 +304,6 @@ mock_assert(const int result, const char *const expression,
 
 #define UNREACHABLE() ISC_UNREACHABLE()
 
-#else /* CPPCHECK */
-
-/*% Require Assertion */
-#define REQUIRE(e) \
-	if (!(e))  \
-	abort()
-/*% Ensure Assertion */
-#define ENSURE(e) \
-	if (!(e)) \
-	abort()
-/*% Insist Assertion */
-#define INSIST(e) \
-	if (!(e)) \
-	abort()
-/*% Invariant Assertion */
-#define INVARIANT(e) \
-	if (!(e))    \
-	abort()
-
-#define UNREACHABLE() abort()
-
-#endif /* CPPCHECK */
-
 #endif /* UNIT_TESTING */
 
 /*
@@ -347,14 +325,8 @@ mock_assert(const int result, const char *const expression,
 
 #else /* UNIT_TESTING */
 
-#ifndef CPPCHECK
 /*% Runtime Check */
 #define RUNTIME_CHECK(cond) ISC_ERROR_RUNTIMECHECK(cond)
-#else /* ifndef CPPCHECK */
-#define RUNTIME_CHECK(e) \
-	if (!(e))        \
-	abort()
-#endif /* ifndef CPPCHECK */
 
 #endif /* UNIT_TESTING */
 
@@ -374,72 +346,7 @@ mock_assert(const int result, const char *const expression,
 #define ISC_ALIGN(x, a) (((x) + (a)-1) & ~((uintmax_t)(a)-1))
 #endif /* ifdef __GNUC__ */
 
-#if HAVE_FUNC_ATTRIBUTE_RETURNS_NONNULL
-#define ISC_ATTR_RETURNS_NONNULL __attribute__((returns_nonnull))
-#else
-#define ISC_ATTR_RETURNS_NONNULL
-#endif
-
-/*
- * Support for malloc attributes.
- */
-#ifdef HAVE_FUNC_ATTRIBUTE_MALLOC
-/*
- * Indicates that a function is malloc-like, i.e., that the
- * pointer P returned by the function cannot alias any other
- * pointer valid when the function returns.
- */
-#define ISC_ATTR_MALLOC __attribute__((malloc))
-#if HAVE_MALLOC_EXT_ATTR
-/*
- * Associates deallocator as a suitable deallocation function
- * for pointers returned from the function marked with the attribute.
- */
-#define ISC_ATTR_DEALLOCATOR(deallocator) __attribute__((malloc(deallocator)))
-/*
- * Similar to ISC_ATTR_DEALLOCATOR, but allows to speficy an index "idx",
- * which denotes the positional argument to which when the pointer is passed
- * in calls to deallocator has the effect of deallocating it.
- */
-#define ISC_ATTR_DEALLOCATOR_IDX(deallocator, idx) \
-	__attribute__((malloc(deallocator, idx)))
-/*
- * Combines both ISC_ATTR_MALLOC and ISC_ATTR_DEALLOCATOR attributes.
- */
-#define ISC_ATTR_MALLOC_DEALLOCATOR(deallocator) \
-	__attribute__((malloc, malloc(deallocator)))
-/*
- * Similar to ISC_ATTR_MALLOC_DEALLOCATOR, but allows to speficy an index "idx",
- * which denotes the positional argument to which when the pointer is passed
- * in calls to deallocator has the effect of deallocating it.
- */
-#define ISC_ATTR_MALLOC_DEALLOCATOR_IDX(deallocator, idx) \
-	__attribute__((malloc, malloc(deallocator, idx)))
-#else /* #ifdef HAVE_MALLOC_EXT_ATTR */
-/*
- * There is support for malloc attribute but not for
- * extended attributes, so macros that combine attribute malloc
- * with a deallocator will only expand to malloc attribute.
- */
-#define ISC_ATTR_DEALLOCATOR(deallocator)
-#define ISC_ATTR_DEALLOCATOR_IDX(deallocator, idx)
-#define ISC_ATTR_MALLOC_DEALLOCATOR(deallocator)	  ISC_ATTR_MALLOC
-#define ISC_ATTR_MALLOC_DEALLOCATOR_IDX(deallocator, idx) ISC_ATTR_MALLOC
-#endif
-#else /* #ifdef HAVE_FUNC_ATTRIBUTE_MALLOC */
-/*
- * There is no support for malloc attribute.
- */
-#define ISC_ATTR_MALLOC
-#define ISC_ATTR_DEALLOCATOR(deallocator)
-#define ISC_ATTR_DEALLOCATOR_IDX(deallocator, idx)
-#define ISC_ATTR_MALLOC_DEALLOCATOR(deallocator)
-#define ISC_ATTR_MALLOC_DEALLOCATOR_IDX(deallocator, idx)
-#endif /* HAVE_FUNC_ATTRIBUTE_MALLOC */
-
 /*%
  * Misc
  */
 #include <isc/deprecated.h>
-
-#endif /* ISC_UTIL_H */
